@@ -18,9 +18,15 @@
 #ifndef __SPICE_VERSION_H__
 #define __SPICE_VERSION_H__
 
+#if !defined(__SPICE_CLIENT_H_INSIDE__) && !defined(SPICE_COMPILATION)
+#warning "Only <spice-client.h> can be included directly"
+#endif
+
 /**
  * SECTION:spice-version
  * @short_description: Spice-Gtk version checking
+ * @title: Version Information
+ * @include: spice-version.h
  *
  * Spice-Gtk provides macros to check the version of the library
  * at compile-time
@@ -40,7 +46,7 @@
  * Spice-Gtk minor version component (e.g. 2 if version is 1.2.3)
  * Since: 0.24
  */
-#define SPICE_GTK_MINOR_VERSION              (29)
+#define SPICE_GTK_MINOR_VERSION              (34)
 
 /**
  * SPICE_GTK_MICRO_VERSION:
